@@ -43,8 +43,7 @@
 
 
 
-
-
+#include <config.h>
 #include "emboss.h"
 #define MODE_STAMP    1
 #define MODE_TCOFFEE  2
@@ -57,6 +56,7 @@
 ** PROTOTYPES  
 **
 ******************************************************************************/
+
 static void domainalign_ProcessStampFile(AjPStr in, 
 					 AjPStr out, 
 					 AjPDomain domain, 
@@ -117,7 +117,6 @@ static void domainalign_tcoffee(AjPDomain domain,
 
 
 
-
 /* @prog domainalign **********************************************************
 **
 ** Generates DAF files (domain alignment files) structure-based sequence 
@@ -160,8 +159,11 @@ int main(int argc, char **argv)
     AjPDomain domain     = NULL; /* Pointer to domain structure.             */
     AjPDomain prevdomain = NULL; /* Pointer to previous domain structure.    */
 
-    ajint     type       = 0;    /* Type of domain (ajSCOP or ajCATH) in the 
-				    DCF file.                                */
+    AjEDomainType type = ajEDomainTypeNULL; /* AJAX Domain Type enumeration
+                                            ** (ajEDomainTypeSCOP or
+                                            ** ajEDomainTypeCATH) in the 
+                                            ** DCF file.
+                                            */
 
     AjPStr   *node       = NULL; /* Node of alignment         .              */
     ajint     noden      = 0;    /*1: Class (SCOP), 2: Fold (SCOP) etc, see 
@@ -174,7 +176,6 @@ int main(int argc, char **argv)
 				       and write them to an output file.         */
 
     AjPStr    temp      = NULL;	/* A temporary string.                       */
-    AjPStr    cmd       = NULL; /* The command line to execute t-coffee.     */
 
 
 
@@ -194,7 +195,6 @@ int main(int argc, char **argv)
     name     = ajStrNew();
     temp     = ajStrNew();
     temp1    = ajStrNew();
-    cmd      = ajStrNew();
     pdbnames = ajStrNew();
 
 
@@ -262,12 +262,12 @@ int main(int argc, char **argv)
     while((domain=(ajDomainReadCNew(dcfin, "*", type))))
     {
 	/* A new family. */
-	if(((domain->Type == ajSCOP) &&
+	if(((domain->Type == ajEDomainTypeSCOP) &&
 	    (((noden==1) && (last_nodeid != domain->Scop->Sunid_Class))      ||
 	     ((noden==2) && (last_nodeid != domain->Scop->Sunid_Fold))       ||
 	     ((noden==3) && (last_nodeid != domain->Scop->Sunid_Superfamily))||
 	     ((noden==4) && (last_nodeid != domain->Scop->Sunid_Family))))   ||
-	   ((domain->Type == ajCATH) &&
+	   ((domain->Type == ajEDomainTypeCATH) &&
 	    (((noden==5) && (last_nodeid != domain->Cath->Class_Id))         ||
 	     ((noden==6) && (last_nodeid != domain->Cath->Arch_Id))          ||
 	     ((noden==7) && (last_nodeid != domain->Cath->Topology_Id))      ||
@@ -451,17 +451,17 @@ int main(int argc, char **argv)
 
     /* Remove all temporary files. */
 
-    ajSysFileUnlink(log);
-    ajSysFileUnlink(dom);
-    ajSysFileUnlink(set);
-    ajSysFileUnlink(scan);
-    ajSysFileUnlink(sort);
-    ajSysFileUnlink(out);
+    ajSysFileUnlinkS(log);
+    ajSysFileUnlinkS(dom);
+    ajSysFileUnlinkS(set);
+    ajSysFileUnlinkS(scan);
+    ajSysFileUnlinkS(sort);
+    ajSysFileUnlinkS(out);
     ajStrAssignS(&temp, name);	
     ajStrAppendC(&temp, ".mat");
-    ajSysFileUnlink(temp);
-    
-    
+    ajSysFileUnlinkS(temp);
+
+
 
     /* Tidy up*/
     ajDomainDel(&domain);
@@ -491,15 +491,13 @@ int main(int argc, char **argv)
     ajFileClose(&logf);
     
     ajExit();
+
     return 0;
 }
 
 
 
 
-
-
-
 /* @funcstatic domainalign_ProcessStampFile ***********************************
 **
 ** This function is very specific to domainalign, hence it is not library code.
@@ -651,7 +649,7 @@ static void domainalign_ProcessStampFile(AjPStr in,
 	 ajFatal("Could not open output file in domainalign_ProcessStampFile");
 
 	
-	if((domain->Type == ajSCOP))
+	if((domain->Type == ajEDomainTypeSCOP))
 	{
 	    ajFmtPrintF(outf,"# TY   SCOP\n# XX\n");
 	    ajFmtPrintF(outf,"# CL   %S",domain->Scop->Class);
@@ -675,7 +673,7 @@ static void domainalign_ProcessStampFile(AjPStr in,
 			    " \t\n\r");
 	    ajFmtPrintF(outf,"# XX\n");
 	}
-	if((domain->Type == ajSCOP))
+	if((domain->Type == ajEDomainTypeSCOP))
 	{
 	    if(noden==1) 
 		ajFmtPrintF(outf,"# SI   %d\n# XX",domain->Scop->Sunid_Class);
@@ -801,7 +799,6 @@ static void domainalign_ProcessStampFile(AjPStr in,
 
 
 
-
 /* @funcstatic domainalign_writelast ******************************************
 **
 ** House-keeping function.
@@ -815,6 +812,7 @@ static void domainalign_ProcessStampFile(AjPStr in,
 ** 
 ** @@
 ****************************************************************************/
+
 static void domainalign_writelast(AjPDomain domain, 
 				  ajint noden, 
 				  AjPStr *last_node, 
@@ -870,6 +868,7 @@ static void domainalign_writelast(AjPDomain domain,
 
 
 
+
 /* @funcstatic domainalign_writeid ********************************************
 **
 ** House-keeping function.
@@ -885,6 +884,7 @@ static void domainalign_writelast(AjPDomain domain,
 ** 
 ** @@
 ****************************************************************************/
+
 static void domainalign_writeid(AjPDomain domain, 
 				ajint noden, 
 				AjPDirout daf, 
@@ -933,8 +933,6 @@ static void domainalign_writeid(AjPDomain domain,
 
 
 
-
-
 /* @funcstatic domainalign_writesid *******************************************
 **
 ** House-keeping function.
@@ -947,6 +945,7 @@ static void domainalign_writeid(AjPDomain domain,
 ** 
 ** @@
 ****************************************************************************/
+
 static 	void domainalign_writesid(AjPDomain domain, 
 				  ajint noden, 
 				  AjPStr *id)
@@ -975,6 +974,7 @@ static 	void domainalign_writesid(AjPDomain domain,
 
 
 
+
 /* @funcstatic domainalign_stamp **********************************************
 **
 ** Call STAMP and process files.
@@ -991,7 +991,7 @@ static 	void domainalign_writesid(AjPDomain domain,
 ** @param [r] set [AjPStr] Name of set file.
 ** @param [r] scan [AjPStr] Name of scan file.
 ** @param [r] sort [AjPStr] Name of sort file.
-** @param [r] log [AjPStr] Lof file name.
+** @param [r] log [AjPStr] Log file name.
 ** @param [r] out [AjPStr] Out file name.
 ** @param [r] keepsinglets [AjBool] Keep singlet sequences or not.
 ** @param [r] moden [ajint] Mode number.
@@ -1003,6 +1003,7 @@ static 	void domainalign_writesid(AjPDomain domain,
 ** @return [void] True on success
 ** @@
 ****************************************************************************/
+
 static void domainalign_stamp(AjPDomain prevdomain,
 			      AjPDomain domain, 
 			      AjPDirout daf, 
@@ -1031,7 +1032,15 @@ static void domainalign_stamp(AjPDomain prevdomain,
     AjPStr    temp      = NULL;	/* A temporary string.                     */
     ajint     x         = 0;    /* Loop counter.                           */
     
-
+    /* TODO: The following parameters are unused. */
+    (void) domain;
+    (void) daf;
+    (void) super;
+    (void) singlets;
+    (void) keepsinglets;
+    (void) moden;
+    (void) nset;
+    
     exec     = ajStrNew();
     line     = ajStrNew();
     temp     = ajStrNew();
@@ -1043,26 +1052,26 @@ static void domainalign_stamp(AjPDomain prevdomain,
     ajDebug("domainalign_stamp name: '%S'\n", name);
     
     /* Call STAMP. */
-    ajFmtPrintS(&exec,	"stamp -l %S -s -n 2 -slide 5 -prefix %S -d %S",
-		dom, name, set);
+    ajFmtPrintS(&exec,	"%S -l %S -s -n 2 -slide 5 -prefix %S -d %S",
+		ajAcdGetpathC("stamp"), dom, name, set);
     ajFmtPrint("\n%S\n\n", exec);
-    ajSysSystem(exec);  
+    ajSysExecS(exec);  
 
-    ajFmtPrintS(&exec, "sorttrans -f %S -s Sc 2.5",
-		scan);
+    ajFmtPrintS(&exec, "%S -f %S -s Sc 2.5",
+		ajAcdGetpathC("sorttrans"), scan);
     ajFmtPrint("\n%S > %S\n\n", exec, sort);
 
-    ajSysSystemOut(exec, sort);
+    ajSysExecOutnameS(exec, sort);
 
-    ajFmtPrintS(&exec, "stamp -l %S -prefix %S",
-		sort, name);
+    ajFmtPrintS(&exec, "%S -l %S -prefix %S",
+		ajAcdGetpathC("stamp"), sort, name);
     ajFmtPrint("\n%S > %S\n\n", exec, log);
-    ajSysSystemOut(exec, log);
+    ajSysExecOutnameS(exec, log);
 	
-    ajFmtPrintS(&exec, "transform -f %S -g  -o %S",
-		sort, alignc);
+    ajFmtPrintS(&exec, "%S -f %S -g  -o %S",
+		ajAcdGetpathC("transform"), sort, alignc);
     ajFmtPrint("\n%S\n\n", exec);
-    ajSysSystem(exec);
+    ajSysExecS(exec);
     
     
     /* Count the number of clusters in the log file. */
@@ -1078,17 +1087,17 @@ static void domainalign_stamp(AjPDomain prevdomain,
     
     /* Call STAMP ... calculate two fields for structural equivalence using 
        threshold Pij value of 0.5, see stamp manual v4.1 pg 27. */
-    ajFmtPrintS(&exec,"poststamp -f %S.%d -min 0.5",
-		name, ncluster);
+    ajFmtPrintS(&exec,"%S -f %S.%d -min 0.5",
+		ajAcdGetpathC("poststamp"), name, ncluster);
     ajFmtPrint("%S\n\n", exec);
-    ajSysSystem(exec);
+    ajSysExecS(exec);
     
     
     /* Call STAMP ... convert block format alignment into clustal format. */
-    ajFmtPrintS(&exec,"ver2hor -f %S.%d.post",
-		name, ncluster); 
+    ajFmtPrintS(&exec,"%S -f %S.%d.post",
+		ajAcdGetpathC("ver2hor"), name, ncluster); 
     ajFmtPrint("%S > %S\n\n", exec, out);
-    ajSysSystemOut(exec, out);
+    ajSysExecOutnameS(exec, out);
     
     
     /* Process STAMP alignment file and generate alignment file for output. */
@@ -1100,11 +1109,11 @@ static void domainalign_stamp(AjPDomain prevdomain,
     for(x=1;x<ncluster+1;x++)
     {
 	ajFmtPrintS(&temp, "%S.%d", name, x);
-	ajSysFileUnlink(temp); 
+	ajSysFileUnlinkS(temp); 
     }
     
     ajFmtPrintS(&temp, "%S.%d.post", name, ncluster);
-    ajSysFileUnlink(temp); 
+    ajSysFileUnlinkS(temp); 
 
     ajStrDel(&exec);
     ajStrDel(&line);
@@ -1115,6 +1124,8 @@ static void domainalign_stamp(AjPDomain prevdomain,
 }   
 
 
+
+
 /* @funcstatic domainalign_tcoffee ********************************************
 **
 ** Call TCOFFEE and process files.
@@ -1130,6 +1141,7 @@ static void domainalign_stamp(AjPDomain prevdomain,
 ** @return [void] True on success
 ** @@
 ****************************************************************************/
+
 static void domainalign_tcoffee(AjPDomain domain, 
 				AjPStr    in, 
 				AjPStr    align, 
@@ -1141,6 +1153,9 @@ static void domainalign_tcoffee(AjPDomain domain,
 {
     AjPStr    exec      = NULL;	/* The UNIX command line to be executed*/
 
+    /* TODO: The following parameters are unused. */
+    (void) alignc;
+
     exec     = ajStrNew();
 
 
@@ -1152,7 +1167,7 @@ static void domainalign_tcoffee(AjPDomain domain,
 
     ajFmtPrintS(&exec,"t_coffee -in %S sap_pair", pdbnames);
     ajFmtPrint("%S > %S\n", exec, in);
-    ajSysSystemOut(exec, in);
+    ajSysExecOutnameS(exec, in);
 
     /* Process tcoffee alignment file and generate alignment file 
        for output. */
@@ -1166,7 +1181,6 @@ static void domainalign_tcoffee(AjPDomain domain,
 
 
 
-
 /* @funcstatic domainalign_ProcessTcoffeeFile *********************************
 **
 ** Parses tcoffee output.
@@ -1180,6 +1194,7 @@ static void domainalign_tcoffee(AjPDomain domain,
 ** @return [void] True on success
 ** @@
 ****************************************************************************/
+
 static void domainalign_ProcessTcoffeeFile(AjPStr in, 
 					   AjPStr align, 
 					   AjPDomain domain,
@@ -1193,7 +1208,9 @@ static void domainalign_ProcessTcoffeeFile(AjPStr in,
     AjPStr  temp3 = NULL;  /* Temporary string. */
     AjPStr   line = NULL;  /* Line of text from input file. */
     
-    
+    /* TODO: The following parameters are unused. */
+    (void) logf;
+
     /* Initialise strings. */
     line    = ajStrNew();
     temp1   = ajStrNew();
@@ -1210,7 +1227,7 @@ static void domainalign_ProcessTcoffeeFile(AjPStr in,
     
 
     /*Write DOMAIN classification records to file*/
-    if((domain->Type == ajSCOP))
+    if((domain->Type == ajEDomainTypeSCOP))
     {
 	ajFmtPrintF(outf,"# TY   SCOP\n# XX\n");
 	ajFmtPrintF(outf,"# CL   %S",domain->Scop->Class);
@@ -1229,7 +1246,7 @@ static void domainalign_ProcessTcoffeeFile(AjPStr in,
 	ajFmtPrintF(outf,"# XX\n");
     }
     
-    if((domain->Type == ajSCOP))
+    if((domain->Type == ajEDomainTypeSCOP))
     {
 	if(noden==1) 
 	    ajFmtPrintF(outf,"# SI   %d\n# XX\n",domain->Scop->Sunid_Class);
@@ -1353,7 +1370,7 @@ static void domainalign_keepsinglets(AjPDomain domain,
 	ajStrAssignS(&hitlist->hits[0]->Dom, ajDomainGetId(domain));
 	
 
-	if((domain->Type == ajSCOP))
+	if((domain->Type == ajEDomainTypeSCOP))
 	{
 	    ajStrAssignS(&hitlist->Class, domain->Scop->Class);
 	    ajStrAssignS(&hitlist->Fold, domain->Scop->Fold);
