@@ -47,6 +47,7 @@
 
 
 
+#include <config.h>
 #include "emboss.h"
 
 
@@ -59,6 +60,7 @@
 ** writes a DAF file extended with the hits.
 **
 ******************************************************************************/
+
 int main(int argc, char **argv)
 {
     AjPList  inseqs    = NULL;  /* Directory of input sequences. Is made to 
@@ -92,7 +94,7 @@ int main(int argc, char **argv)
 
     AjPFile    logf    = NULL;  /* Log file pointer                          */
 
-    ajint x=0;                  /* Loop counter                              */
+    ajuint x=0;                 /* Loop counter                              */
     AjPStr  cmd        = NULL;  /* Executable command                        */
    
     AjPFile alg_in     = NULL;  /* the alignment file for reading            */
@@ -150,7 +152,7 @@ int main(int argc, char **argv)
   
 
     /* ACD processing */
-    embInitP("seqalign",argc,argv,"DOMALIGN");
+    embInitPV("seqalign",argc,argv,"DOMALIGN",VERSION);
 
     inseqsdhf = ajAcdGetDirlist("dhfinpath");
     inseqsdaf = ajAcdGetDirlist("dafinpath");
@@ -232,7 +234,7 @@ int main(int argc, char **argv)
 		    ok = ajTrue;
 	    }
 	    else
-		if(scopalign->N)
+		if(scopalign->Number)
 		    ok = ajTrue;
 	    ajFileClose(&inf);
 	    
@@ -484,23 +486,24 @@ int main(int argc, char **argv)
 	if(modei==2)
 	{
 	    /* Alignment is available: do profile to sequence mode. */
-	    ajFmtPrintS(&cmd,"clustalw -type=protein -profile1=%S -sequences"
+	    ajFmtPrintS(&cmd,"%S -type=protein -profile1=%S -sequences"
 			" -profile2=%S -MATRIX=BLOSUM -GAPOPEN=10"
 			" -GAPEXT=0.5 -outfile=%S\n",
-			clustin1,clustin2,clustout);
+			ajAcdGetpathC("clustalw"),
+                        clustin1,clustin2,clustout);
 	}	
 	/* Such cases will now no longer occur ... but keep here for time
 	   being. */
 	else if(modei==1)
 	{
 	    /* Alignment is NOT available: multiple sequence mode. */
-	    ajFmtPrintS(&cmd,"clustalw -infile=%S -align"
+	    ajFmtPrintS(&cmd,"%S -infile=%S -align"
 			" -MATRIX=BLOSUM -GAPOPEN=10"
 			" -GAPEXT=0.5 -outfile=%S\n",
-			clustin2,clustout);
+			ajAcdGetpathC("clustalw"), clustin2,clustout);
 	}	
 	ajFmtPrint("\n%S\n", cmd);
-	system(ajStrGetPtr(cmd));
+	ajSysExecS(cmd);
 	    
 	    
 	/* Reformat output file into domain alignment format. */
@@ -525,7 +528,7 @@ int main(int argc, char **argv)
 	{
 	    if(scopalign)
 	    {
-		if(scopalign->Type == ajSCOP)
+		if(scopalign->Type == ajEDomainTypeSCOP)
 		    ajFmtPrintF(alg_out,"# TY   SCOP\n# XX\n");
 		else
 		    ajFmtPrintF(alg_out,"# TY   CATH\n# XX\n");
@@ -542,7 +545,7 @@ int main(int argc, char **argv)
 	{
 	    if(hit_sing)
 	    {
-		if(hit_sing->Type == ajSCOP)
+		if(hit_sing->Type == ajEDomainTypeSCOP)
 		    ajFmtPrintF(alg_out,"# TY   SCOP\n# XX\n");
 		else
 		    ajFmtPrintF(alg_out,"# TY   CATH\n# XX\n");
@@ -584,12 +587,12 @@ int main(int argc, char **argv)
 
 	/* Clean up directory. */
 	if(modei==2)
-	    if(scopalign->N !=0)
-		ajSysFileUnlink(clustin1);
+	    if(scopalign->Number !=0)
+		ajSysFileUnlinkS(clustin1);
 	
-	ajSysFileUnlink(clustin2);
-	ajSysFileUnlink(clustout);
-	ajSysFileUnlink(clustdnd);  
+	ajSysFileUnlinkS(clustin2);
+	ajSysFileUnlinkS(clustout);
+	ajSysFileUnlinkS(clustdnd);  
 	
 	
 	/* Free memory. */
@@ -620,8 +623,10 @@ int main(int argc, char **argv)
     ajStrDel(&cmd);
     ajListstrFree(&inseqsdhf);
     ajListstrFree(&inseqsdaf);
+    ajDirDel(&dhfin);
     ajDiroutDel(&dafout);
     ajStrDel(&tmp_name);
+    ajStrDel(&outname);
     ajStrDel(&clustin1);
     ajStrDel(&clustin2);
     ajStrDel(&clustout);
